==> crm-commom-vo-1.2.2.27.release.jar: com/biz/crm/nebular/dms/repfeepool/RepFeePoolBpmVo.java <==
package com.biz.crm.nebular.dms.repfeepool;

import com.biz.crm.nebular.mdm.CrmExtVo;
import io.swagger.annotations.ApiModelProperty;
import java.math.BigDecimal;
import java.util.List;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * 货补费用池操作记录表
 * @Author: chenrong
 * @Date: 2020/12/24 15:49
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class RepFeePoolBpmVo extends CrmExtVo {

  private static final long serialVersionUID = 1836645816551287737L;

  /**
   * 编码
   */
  private String code;
  /**
   * 数量调整类型
   */
  private Integer adjustCountType;
  /**
   * 金额调整类型
   */
  private Integer adjustFeeType;
  /**
   * 审批状态
   */
  private Integer bpmState;
  /**
   * 客户编码
   */
  private String cusCode;
  /**
   * 客户名称
   */
  private String cusName;
  /**
   * 销售公司编码
   */
  private String saleCompanyCode;
  /**
   * 销售公司名称
   */
  private String saleCompanyName;
  /**
   * 产品编码
   */
  private String productCode;
  /**
   * 产品名称
   */
  private String productName;
  /**
   * 单位编码
   */
  private String unitCode;
  /**
   * 单位名称
   */
  private String unitName;
  /**
   * 调整数量
   */
  private BigDecimal adjustCount;
  /**
   * 调整价格
   */
  private BigDecimal price;
  /**
   * 调整金额
   */
  private BigDecimal adjustFee;
  /**
   * 审批人账号
   */
  private String bpmAccount;
  /**
   * 审批人姓名
   */
  private String bpmFullName;
  /**
   * 审批时间
   */
  private String bpmTime;
  /**
   * 录单时间
   */
  private String createTime;
  /**
   * 提交时间
   */
  private String commitTime;
  /**
   * 费用池明细编码
   */
  private String repFeePoolItemCode;
  /**
   * 货补费用池唯一约束字典编码
   */
  @ApiModelProperty(value = "货补费用池唯一约束字典编码")
  private String uniqueDictCode;
  /**
   * 扣减顺序字典编码
   */
  private String indexDictCode;
  /**
   * 调整原因
   */
  private String adjustReason;
  /**
   * 来源编码
   */
  private String resourceCode;
  /**
   * 文件列表
   */
  private List<RepFeePoolFileVo>  files;
  /**
   * 冗余字段：审批状态集合
   */
  private List<String> bpmStates;
  /**
   * 冗余字段：调整方式：自动/手工
   */
  private String adjustMethod;
  /**
   * 调整前数量
   */
  private BigDecimal beforeAvailableCount;
  /**
   * 调整前金额
   */
  private BigDecimal beforeAvailableFee;
  /**
   * 销售价
   */
  private BigDecimal salePrice;
  /**
   * 成本价
   */
  private BigDecimal costPrice;
}

==> crm-commom-vo-1.3.0.6.3.release.jar: com/biz/crm/nebular/dms/repfeepool/RepFeePoolBpmVo.java <==
package com.biz.crm.nebular.dms.repfeepool;

import com.biz.crm.nebular.mdm.CrmExtVo;
import io.swagger.annotations.ApiModelProperty;
import java.math.BigDecimal;
import java.util.List;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * 货补费用池操作记录表
 * @Author: chenrong
 * @Date: 2020/12/24 15:49
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class RepFeePoolBpmVo extends CrmExtVo {

  private static final long serialVersionUID = 1836645816551287737L;

  /**
   * 编码
   */
  private String code;
  /**
   * 数量调整类型
   */
  private Integer adjustCountType;
  /**
   * 金额调整类型
   */
  private Integer adjustFeeType;
  /**
   * 审批状态
   */
  private Integer bpmState;
  /**
   * 客户编码
   */
  private String cusCode;
  /**
   * 客户名称
   */
  private String cusName;
  /**
   * 销售公司编码
   */
  private String saleCompanyCode;
  /**
   * 销售公司名称
   */
  private String saleCompanyName;
  /**
   * 产品编码
   */
  private String productCode;
  /**
   * 产品名称
   */
  private String productName;
  /**
   * 单位编码
   */
  private String unitCode;
  /**
   * 单位名称
   */
  private String unitName;
  /**
   * 调整数量
   */
  private BigDecimal adjustCount;
  /**
   * 调整价格
   */
  private BigDecimal price = BigDecimal.ZERO;
  /**
   * 调整金额
   */
  private BigDecimal adjustFee = BigDecimal.ZERO;
  /**
   * 审批人账号
   */
  private String bpmAccount;
  /**
   * 审批人姓名
   */
  private String bpmFullName;
  /**
   * 审批时间
   */
  private String bpmTime;
  /**
   * 录单时间
   */
  private String createTime;
  /**
   * 提交时间
   */
  private String commitTime;
  /**
   * 费用池明细编码
   */
  private String repFeePoolItemCode;
  /**
   * 货补费用池唯一约束字典编码
   */
  @ApiModelProperty(value = "货补费用池唯一约束字典编码")
  private String uniqueDictCode;
  /**
   * 扣减顺序字典编码
   */
  private String indexDictCode;
  /**
   * 调整原因
   */
  private String adjustReason;
  /**
   * 来源编码
   */
  private String resourceCode;
  /**
   * 文件列表
   */
  private List<RepFeePoolFileVo>  files;
  /**
   * 冗余字段：审批状态集合
   */
  private List<String> bpmStates;
  /**
   * 冗余字段：调整方式：自动/手工
   */
  private String adjustMethod;
  /**
   * 调整前数量
   */
  private BigDecimal beforeAvailableCount;
  /**
   * 调整前金额
   */
  private BigDecimal beforeAvailableFee;
  /**
   * 销售价
   */
  private BigDecimal salePrice = BigDecimal.ZERO;
  /**
   * 成本价
   */
  private BigDecimal costPrice = BigDecimal.ZERO;

  /**
   * 成本调整金额
   */
  private BigDecimal adjustCostFee = BigDecimal.ZERO;

  /**
   * 销售调整金额
   */
  private BigDecimal adjustSaleFee = BigDecimal.ZERO;
  /**
   * 办事处编码
   */
  private String officeCode;
  /**
   * 办事处名称
   */
  private String officeName;
}
